﻿/*
	Das ist ein Autohotkey v1 Script
	
	Es basiert auf dem "PopupFolder"-Script von Func
	
	Der Ordner "IconMenuLauncher" mit den Dateien "ExtractIcon.ahk" und "Watchfolder.ahk"
	müssen im selben Verzeichnis abgelegt werden wie das Skript "IconMenuLauncher.ahk".
	
	Beim Start dieses Script, wird an der Mausposition eine Liste aller Dateien vom unten festgelegten Ordnerpfad angezeigt.
	Programme und Dateien können von dieser Liste aus gestartet werden.

	In Windows 11 kann man auf dem Desktop eine Verknüpfung erstellen und beim Speicherort des Elements:
	C:\Windows\Explorer.exe "C:\Pfad\Zum\Spript.ahk" -- eingeben und einen Namen festlegen.
	Icon kann anschliessend über Rechtsklick - Eigenschaften - Anderes Symbol noch angepasst werden.
	Die Verknüpfung gilt dann als Programm und kann auch an der Windows 11 Taskleiste angeheftet werden.
	So hat man eine Art Quick Launch.

	Dieses Script ist ein Work-In-Progress.
	Verbesserungen und Vereinfachungen sind Willkommen.
	
	- Es fehlt die Option zur Deaktivierung der Dateierweiterungen.
	- Es fehlen die Optionen für Rechtsklick
	- Es fehlen die Optionen zum Ausschliessen von Dateien und Ordnern
	- Reaktionszeiten verbessern
	- Tooltips bei MouseOver
	
*/
; ---------------------------------------------------------------------------

; BITTE FOLGENDE PUNKTE FESTLEGEN:

; Ordnerpfad bestimmem, welcher durchsucht werden soll (Pfad muss ohne Backslash enden!)
rootdir = %A_Appdata%\Microsoft\Internet Explorer\Quick Launch

; Sollen Datei-Icons angezeigt werden? (On = Ja / Off = Nein)
ShowIcons = On

; Soll der Pfadordner im Hauptmenü angezeigt werden? (On = Ja / Off = Nein)
ShowOpenFolder = On

; Wenn der Pfadordner im Hauptmenü eingeschaltet ist:
; Soll der Pfadordners oben oder unten in der Liste angezeigt werden? (On = Oben / Off = Unten)
ShowOpenFolderOnTop = On

; Soll ein "Skript bearbeiten"-Eintrag im Hauptmenü angezeigt werden? (On = Ja / Off = Nein)
ShowEditScript = On

; Wenn die Anzeige "Skript bearbeiten" eingeschaltet ist:
; Soll die Anzeige oben oder unten in der Liste erscheinen? (On = Oben / Off = Unten)
ShowEditScriptOnTop = On

; Soll eine Trennlinie zwischen den Menüeinträgen erscheinen? (On = Ja / Off = Nein)
ShowSeparator = Off

; Soll ein Pfadordner in Untermenüs angezeigt werden? (On = Ja / Off = Nein)
ShowSubFolderPath = On

; Programm zur Bearbeitung des Skriptes festlegen (Standardmässig Notepad.exe, kann z.B. mit "Notepad++.exe" ersetzt werden)
EditProgram = notepad.exe					; Je nach Programm muss der vollständige Pfad angegeben werden

; Grösse der Icons, welche aus der Shell32.dll Datei extrahiert werden
IconSize = 16								; Klein = 16 / Mittel = 24 / Gross = 32 (oder einfach gewünschte Grösse eingeben)

; ---------------------------------------------------------------------------

	
; Kein Icon im Infobereich anzeigen
#NoTrayIcon

; Wenn der Ordnerpfad (Rootdir) nicht korrekt ist
If !FileExist(rootdir)
	{
	;GUI (mit Text und Buttons) erstellen
	#NoEnv
	#SingleInstance force
	Gui, Add, Text, x10 y15, Der angegebene Ordnerpfad`n%rootdir%`nexistiert nicht oder ist falsch geschrieben.`n`nBitte auch sicherstellen, dass der Pfad nicht mit einem Backslash endet.
	Gui, Add, Button, gButtonSkript x10 y95 Default, Skript bearbeiten
	Gui, Add, Button, gButtonExit x380 y95, Beenden
	Gui, Show, w450 h130, ROOTDIR existiert nicht!
	return
	
	; Funktionen der Buttons definieren
	ButtonSkript:								; Wenn der Button "Skript bearbeiten" gedrückt wird
	Run, %EditProgram% "%A_ScriptFullPath%"		; Öffne mit oben festgelegten Editor dieses Skript
	ExitApp
	Return
	
	ButtonExit:									; Wenn der Button "Beenden" gedrückt wird
	ExitApp 									; Schliesse das Skript
	Return

	GuiClose:									; Wenn bei GUI (X) gedrückt wird
	ExitApp 									; Schliesse das Skript
	Return
	}


#SingleInstance Force
#Persistent
SetBatchLines, -1

#Include %A_ScriptDir%\IconMenuLauncher\WatchFolder.ahk
#Include %A_ScriptDir%\IconMenuLauncher\ExtractIcon.ahk


GoSub CreateMenu
WatchFolder(rootdir, "Update", SubTree := True, Watch := 0x03)
Menu, %rootdir%, Show ; Show the menu immediately after creating it
Return


Update(Folder, Changes)
	{
	GoSub CreateMenu
	}


CreateMenu:

	If ShowOpenFolder=On
		{
		If ShowOpenFolderOnTop=On
			{
			Menu, %rootdir%, add, %rootdir%, OpenFolder
			ExtractIcon(rootdir, %A_LoopFileName% . rootdir)
			Menu, %rootdir%, Add
			}
		}
		If ShowEditScript=On
		{
			If ShowEditScriptOnTop=On
			{
			Menu, %rootdir%, add, Skript zur Bearbeitung öffnen , OpenFile
			Menu, %rootdir%, Icon, Skript zur Bearbeitung öffnen, C:\Windows\system32\shell32.dll,72, %iconsize% , OpenFile
			Menu, %rootdir%, Add
			}
		}	
	
	Loop, %rootdir%\*.*, 2, 1 ; Folders only
		{
		if A_LoopFileAttrib contains H,R,S  ; Dateien, welche das Attibut H (versteckt), R (schreibgeschützt) oder S (System) haben. Hinweis: Keine Zwischenräume bei "H,R,S"
		continue  							; Datei überspringen
		StringGetPos, pos, A_LoopFileLongPath, \, R
		if (pos <> -1) ; it has a parent
			StringLeft, ParentFolderDirectory, A_LoopFileLongPath, %pos%
		if (pos = -1) ; it has no parent 
			ParentFolderDirectory := rootdir
		
		Menu, %A_LoopFileLongPath%, add
		
		If ShowSubFolderPath=on
		{
		Menu, %A_LoopFileLongPath%, add, Öffne: %A_LoopFileName%, OpenFolder
		ExtractIcon(A_LoopFileLongPath, "Öffne: " . A_LoopFileName)
		Menu, %A_LoopFileLongPath%, add
		}
		
		If ShowSeparator=On
			{
			Menu, %A_LoopFileLongPath%, add
			}
		
		Menu, %ParentFolderDirectory%, add, %A_LoopFileName%, :%A_LoopFileLongPath%
		ExtractIcon(ParentFolderDirectory, A_LoopFileName)
				
		If ShowSeparator=On
			{
			Menu, %ParentFolderDirectory%, add
			}

		}

	Loop, %rootdir%\*.*, 0, 1 ; Files only
		{
		;msgbox % A_LoopFileLongPath
		if A_LoopFileAttrib contains H,R,S  ; Dateien, welche das Attibut H (versteckt), R (schreibgeschützt) oder S (System) haben. Hinweis: Keine Zwischenräume bei "H,R,S"
		continue  							; Datei überspringen
		StringGetPos, pos, A_LoopFileLongPath, \, R
			if (pos <> -1) ; it has a parent
				StringLeft, ParentFolderDirectory, A_LoopFileLongPath, %pos%
			if (pos = -1) ; it has no parent 
				ParentFolderDirectory := rootdir
		
		Menu, %ParentFolderDirectory%, add, %A_LoopFileName%, OpenFile

		
		If ShowIcons=On
			{
			ExtractIcon(ParentFolderDirectory, A_LoopFileName)
			}
		
		If ShowSeparator=On
			{
			Menu, %ParentFolderDirectory%, add
			}
		}
	
	If ShowOpenFolder=On
		{
		If ShowOpenFolderOnTop=Off
			{
			Menu, %rootdir%, Add
			Menu, %rootdir%, add, %rootdir%, OpenFolder
			ExtractIcon(rootdir, %A_LoopFileName% . rootdir)
			}
		}
		
		If ShowEditScript=On
		{
		If ShowEditScriptOnTop=Off
			{
			Menu, %rootdir%, Add
			Menu, %rootdir%, add, Skript zur Bearbeitung öffnen , OpenFile
			Menu, %rootdir%, Icon, Skript zur Bearbeitung öffnen, C:\Windows\system32\shell32.dll,72, %iconsize% , OpenFile
			}
		}
		
Return


OpenFile:
    If ( A_ThisMenuItem = "Skript zur Bearbeitung öffnen" )
    {	Run, %EditProgram% "%A_ScriptFullPath%"
	}
	else
	{	Run %A_ThisMenu%\%A_ThisMenuItem%
	}
	ExitApp
		
return


OpenFolder:
	run %A_ThisMenu%
	ExitApp
	
return
